# teralytic
Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.5
- Package version: 1.0.5-32
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import teralytic 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import teralytic
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import teralytic
from teralytic.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: OAuth2
teralytic.configuration.access_token = 'YOUR_ACCESS_TOKEN'
# create an instance of the API class
api_instance = teralytic.FieldApi()
organization_id = 'organization_id_example' # str | id of Organization to retrieve
field_id = 'field_id_example' # str | id of Field to retrieve

try:
    # List single Field details associated with Field id provided (from set of Fields associated with the account key)
    api_response = api_instance.field_get(organization_id, field_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling FieldApi->field_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.teralytic.io/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*FieldApi* | [**field_get**](docs/FieldApi.md#field_get) | **GET** /organizations/{organization_id}/fields/{field_id} | List single Field details associated with Field id provided (from set of Fields associated with the account key)
*FieldApi* | [**field_list**](docs/FieldApi.md#field_list) | **GET** /organizations/{organization_id}/fields | List all Fields associated with account key
*OrganizationApi* | [**organization_get**](docs/OrganizationApi.md#organization_get) | **GET** /organizations/{organization_id} | List single Organization details associated with Organization id provided
*OrganizationApi* | [**organization_list**](docs/OrganizationApi.md#organization_list) | **GET** /organizations | List all Organizations associated with account key
*OrganizationApi* | [**organization_reading_list**](docs/OrganizationApi.md#organization_reading_list) | **GET** /organizations/{organization_id}/readings | List all Readings associated with account key
*ProbeApi* | [**probe_get**](docs/ProbeApi.md#probe_get) | **GET** /organizations/{organization_id}/probes/{probe_id} | List single Probe details, including Reading data, associated with Probe id provided (from set of Fields associated with the account key)
*ProbeApi* | [**probe_list**](docs/ProbeApi.md#probe_list) | **GET** /organizations/{organization_id}/probes | List all Probes associated with account key


## Documentation For Models

 - [DepthReading](docs/DepthReading.md)
 - [Error](docs/Error.md)
 - [Field](docs/Field.md)
 - [FieldGeometry](docs/FieldGeometry.md)
 - [FieldGeometryGeometry](docs/FieldGeometryGeometry.md)
 - [MicroClimateData](docs/MicroClimateData.md)
 - [Organization](docs/Organization.md)
 - [Probe](docs/Probe.md)
 - [Reading](docs/Reading.md)
 - [ReadingLocation](docs/ReadingLocation.md)
 - [WeatherData](docs/WeatherData.md)


## Documentation For Authorization


## OAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **https://api.teralytic.io/organization.read**: Read organization properties
 - **https://api.teralytic.io/probe.read**: Read probe properties and data
 - **https://api.teralytic.io/field.read**: Read field properties and data
 - **https://api.teralytic.io/reading.read**: Read sensor readings


## Author



